import { GeneratedType, OfflineSigner } from '@cosmjs/proto-signing';
import { DeliverTxResponse, SigningStargateClient, SigningStargateClientOptions, StdFee } from '@cosmjs/stargate';
import { MsgAssociateBondResponse, MsgDeleteNameResponse, MsgDissociateBondResponse, MsgDissociateRecordsResponse, MsgReassociateRecordsResponse, MsgReserveAuthorityResponse, MsgSetAuthorityBondResponse, MsgSetNameResponse, MsgSetRecordResponse } from './proto/cerc/registry/v1/tx';
import { MsgCommitBidResponse, MsgCreateAuctionResponse, MsgReleaseFundsResponse, MsgRevealBidResponse } from './proto/cerc/auction/v1/tx';
import { MsgCancelBondResponse, MsgCreateBondResponse, MsgRefillBondResponse, MsgWithdrawBondResponse } from './proto/cerc/bond/v1/tx';
import { MsgOnboardParticipantResponse } from './proto/cerc/onboarding/v1/tx';
import { EthPayload } from './proto/cerc/onboarding/v1/onboarding';
export declare const laconicDefaultRegistryTypes: ReadonlyArray<[string, GeneratedType]>;
export declare class LaconicClient extends SigningStargateClient {
    static connectWithSigner(endpoint: string, signer: OfflineSigner, options?: SigningStargateClientOptions): Promise<LaconicClient>;
    createBond(signer: string, denom: string, amount: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgCreateBondResponse>;
    refillBond(signer: string, denom: string, amount: string, id: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgRefillBondResponse>;
    withdrawBond(signer: string, denom: string, amount: string, id: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgWithdrawBondResponse>;
    cancelBond(signer: string, id: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgCancelBondResponse>;
    associateBond(signer: string, recordId: string, bondId: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgAssociateBondResponse>;
    dissociateBond(signer: string, recordId: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgDissociateBondResponse>;
    dissociateRecords(signer: string, bondId: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgDissociateRecordsResponse>;
    reassociateRecords(signer: string, oldBondId: string, newBondId: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgReassociateRecordsResponse>;
    reserveAuthority(signer: string, name: string, owner: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgReserveAuthorityResponse>;
    commitBid(signer: string, auctionId: string, commitHash: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgCommitBidResponse>;
    revealBid(signer: string, auctionId: string, reveal: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgRevealBidResponse>;
    setRecord(params: {
        privateKey: string;
        record: any;
        bondId: string;
    }, signer: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgSetRecordResponse>;
    setAuthorityBond(signer: string, bondId: string, name: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgSetAuthorityBondResponse>;
    setName(signer: string, lrn: string, cid: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgSetNameResponse>;
    deleteName(signer: string, lrn: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgDeleteNameResponse>;
    parseResponse<T>(response: DeliverTxResponse): T;
    processWriteError(error: string): string;
    onboardParticipant(signer: string, ethPayload: EthPayload, ethSignature: string, role: string, kycId: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgOnboardParticipantResponse>;
    createAuction(signer: string, kind: string, commitsDuration: string, revealsDuration: string, denom: string, commitFee: string, revealFee: string, minimumBid: string, maxPrice: string, numProviders: number, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgCreateAuctionResponse>;
    releaseFunds(signer: string, auctionId: string, fee: StdFee | 'auto' | number, memo?: string): Promise<MsgReleaseFundsResponse>;
}
