"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LaconicClient = exports.laconicDefaultRegistryTypes = void 0;
const long_1 = __importDefault(require("long"));
const proto_signing_1 = require("@cosmjs/proto-signing");
const stargate_1 = require("@cosmjs/stargate");
const tendermint_rpc_1 = require("@cosmjs/tendermint-rpc");
const message_1 = require("./types/cerc/bond/message");
const coin_1 = require("./proto/cosmos/base/v1beta1/coin");
const message_2 = require("./types/cerc/registry/message");
const message_3 = require("./types/cerc/auction/message");
const message_4 = require("./types/cerc/onboarding/message");
const tx_1 = require("./proto/cerc/registry/v1/tx");
const registry_1 = require("./proto/cerc/registry/v1/registry");
const account_1 = require("./account");
const util_1 = require("./util");
const message_5 = require("./types/cosmos/bank/message");
const duration_1 = require("./proto/google/protobuf/duration");
const DEFAULT_WRITE_ERROR = 'Unable to write to laconicd.';
exports.laconicDefaultRegistryTypes = [
    ...stargate_1.defaultRegistryTypes,
    ...message_1.bondTypes,
    ...message_2.registryTypes,
    ...message_3.auctionTypes,
    ...message_5.bankTypes,
    ...message_4.onboardingTypes
];
function createDefaultRegistry() {
    return new proto_signing_1.Registry(exports.laconicDefaultRegistryTypes);
}
class LaconicClient extends stargate_1.SigningStargateClient {
    static connectWithSigner(endpoint, signer, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const cometClient = yield tendermint_rpc_1.Comet38Client.connect(endpoint);
            return new LaconicClient(cometClient, signer, Object.assign({ registry: createDefaultRegistry() }, options));
        });
    }
    createBond(signer, denom, amount, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_1.typeUrlMsgCreateBond,
                value: {
                    signer,
                    coins: [
                        coin_1.Coin.fromPartial({
                            denom,
                            amount
                        })
                    ]
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    refillBond(signer, denom, amount, id, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_1.typeUrlMsgRefillBond,
                value: {
                    id,
                    signer,
                    coins: [
                        coin_1.Coin.fromPartial({
                            denom,
                            amount
                        })
                    ]
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    withdrawBond(signer, denom, amount, id, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_1.typeUrlMsgWithdrawBond,
                value: {
                    id,
                    signer,
                    coins: [
                        coin_1.Coin.fromPartial({
                            denom,
                            amount
                        })
                    ]
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    cancelBond(signer, id, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_1.typeUrlMsgCancelBond,
                value: {
                    id,
                    signer
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    associateBond(signer, recordId, bondId, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_2.typeUrlMsgAssociateBond,
                value: {
                    recordId,
                    bondId,
                    signer
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    dissociateBond(signer, recordId, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_2.typeUrlMsgDissociateBond,
                value: {
                    recordId,
                    signer
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    dissociateRecords(signer, bondId, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_2.typeUrlMsgDissociateRecords,
                value: {
                    signer,
                    bondId
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    reassociateRecords(signer, oldBondId, newBondId, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_2.typeUrlMsgReassociateRecords,
                value: {
                    signer,
                    oldBondId,
                    newBondId
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    reserveAuthority(signer, name, owner, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_2.typeUrlMsgReserveAuthority,
                value: {
                    name,
                    signer,
                    owner
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    commitBid(signer, auctionId, commitHash, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_3.typeUrlMsgCommitBid,
                value: {
                    signer,
                    auctionId,
                    commitHash
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    revealBid(signer, auctionId, reveal, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_3.typeUrlMsgRevealBid,
                value: {
                    signer,
                    auctionId,
                    reveal
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    setRecord(params, signer, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const registryRecord = registry_1.Record.fromPartial({ attributes: Buffer.from(JSON.stringify(params.record), 'binary') });
            // Sign record.
            const recordSignerAccount = new account_1.Account(Buffer.from(params.privateKey, 'hex'));
            yield recordSignerAccount.init();
            const messageToSign = util_1.Util.sortJSON(params.record);
            const sig = yield recordSignerAccount.signRecord(messageToSign);
            const signature = registry_1.Signature.fromJSON({ sig: sig.toString('base64'), pubKey: recordSignerAccount.registryPublicKey });
            const payload = tx_1.Payload.fromJSON({ record: registryRecord, signatures: [signature] });
            const createMsg = {
                typeUrl: message_2.typeUrlMsgSetRecord,
                value: {
                    signer,
                    bondId: params.bondId,
                    payload
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    setAuthorityBond(signer, bondId, name, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_2.typeUrlMsgSetAuthorityBond,
                value: {
                    signer,
                    bondId,
                    name
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    setName(signer, lrn, cid, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_2.typeUrlMsgSetName,
                value: {
                    signer,
                    lrn,
                    cid
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    deleteName(signer, lrn, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_2.typeUrlMsgDeleteName,
                value: {
                    signer,
                    lrn
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    parseResponse(response) {
        if (response.code !== 0) {
            // Throw error when transaction is not successful.
            throw new Error(this.processWriteError(response.rawLog || 'No raw log in response'));
        }
        return this.registry.decode(response.msgResponses[0]);
    }
    processWriteError(error) {
        const errorMessage = [...message_2.NAMESERVICE_ERRORS, ...message_3.AUCTION_ERRORS, message_4.ONBOARDING_DISABLED_ERROR].find(message => error.includes(message));
        if (!errorMessage) {
            console.error(error);
        }
        return `${errorMessage || DEFAULT_WRITE_ERROR}: ${error}`;
    }
    onboardParticipant(signer, ethPayload, ethSignature, role, kycId, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const onboardParticipantMsg = {
                typeUrl: message_4.typeUrlMsgOnboardParticipant,
                value: {
                    participant: signer,
                    ethPayload,
                    ethSignature,
                    role,
                    kycId
                }
            };
            const response = yield this.signAndBroadcast(signer, [onboardParticipantMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    createAuction(signer, kind, commitsDuration, revealsDuration, denom, commitFee, revealFee, minimumBid, maxPrice, numProviders, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createAuctionMsg = {
                typeUrl: message_3.typeUrlMsgCreateAuction,
                value: {
                    signer,
                    kind,
                    commitsDuration: duration_1.Duration.fromPartial({ seconds: long_1.default.fromString(commitsDuration) }),
                    revealsDuration: duration_1.Duration.fromPartial({ seconds: long_1.default.fromString(revealsDuration) }),
                    commitFee: coin_1.Coin.fromPartial({ amount: commitFee, denom }),
                    revealFee: coin_1.Coin.fromPartial({ amount: revealFee, denom }),
                    minimumBid: coin_1.Coin.fromPartial({ amount: minimumBid, denom }),
                    maxPrice: coin_1.Coin.fromPartial({ amount: maxPrice, denom }),
                    numProviders
                }
            };
            const response = yield this.signAndBroadcast(signer, [createAuctionMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
    releaseFunds(signer, auctionId, fee, memo = '') {
        return __awaiter(this, void 0, void 0, function* () {
            const createMsg = {
                typeUrl: message_3.typeUrlMsgReleaseFunds,
                value: {
                    signer,
                    auctionId
                }
            };
            const response = yield this.signAndBroadcast(signer, [createMsg], fee, memo);
            return this.parseResponse(response);
        });
    }
}
exports.LaconicClient = LaconicClient;
