import { Coin } from "../../../cosmos/base/v1beta1/coin";
import Long from "long";
import _m0 from "protobufjs/minimal";
export declare const protobufPackage = "cerc.auction.v1";
/** Params defines the auction module parameters */
export interface Params {
}
/** Auction represents a sealed-bid on-chain auction */
export interface Auction {
    id: string;
    /** Auction kind (vickrey | provider) */
    kind: string;
    status: string;
    /** Address of the creator of the auction */
    ownerAddress: string;
    /** Timestamp at which the auction was created */
    createTime?: Date;
    /** Timestamp at which the commits phase concluded */
    commitsEndTime?: Date;
    /** Timestamp at which the reveals phase concluded */
    revealsEndTime?: Date;
    /**
     * Commit and reveal fees must both be paid when committing a bid
     * Reveal fee is returned only if the bid is revealed
     */
    commitFee?: Coin;
    revealFee?: Coin;
    /**
     * Minimum acceptable bid amount for a valid commit
     * Only applicable in vickrey auctions
     */
    minimumBid?: Coin;
    /**
     * Addresses of the winners
     * (single winner for vickrey auction)
     * (multiple winners for provider auctions)
     */
    winnerAddresses: string[];
    /** Winning bids, i.e. the best bids */
    winningBids: Coin[];
    /**
     * Auction winning price
     * vickrey auction: second highest bid, paid by the winner
     * provider auction: higest bid amongst winning_bids, paid by auction creator
     * to each winner
     */
    winningPrice?: Coin;
    /**
     * Maximum acceptable bid amount for a valid commit
     * Only applicable in provider auctions
     */
    maxPrice?: Coin;
    /**
     * Number of desired providers (num of auction winners)
     * Only applicable in provider auctions
     */
    numProviders: number;
    fundsReleased: boolean;
}
/** Auctions represent all the auctions in the module */
export interface Auctions {
    auctions: Auction[];
}
/** Bid represents a sealed bid (commit) made during the auction */
export interface Bid {
    auctionId: string;
    bidderAddress: string;
    status: string;
    commitHash: string;
    commitTime?: Date;
    commitFee?: Coin;
    revealTime?: Date;
    revealFee?: Coin;
    bidAmount?: Coin;
}
export declare const Params: {
    encode(_: Params, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Params;
    fromJSON(_: any): Params;
    toJSON(_: Params): unknown;
    fromPartial<I extends {} & {} & { [K in Exclude<keyof I, never>]: never; }>(_: I): Params;
};
export declare const Auction: {
    encode(message: Auction, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Auction;
    fromJSON(object: any): Auction;
    toJSON(message: Auction): unknown;
    fromPartial<I extends {
        id?: string | undefined;
        kind?: string | undefined;
        status?: string | undefined;
        ownerAddress?: string | undefined;
        createTime?: Date | undefined;
        commitsEndTime?: Date | undefined;
        revealsEndTime?: Date | undefined;
        commitFee?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        revealFee?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        minimumBid?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        winnerAddresses?: string[] | undefined;
        winningBids?: {
            denom?: string | undefined;
            amount?: string | undefined;
        }[] | undefined;
        winningPrice?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        maxPrice?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        numProviders?: number | undefined;
        fundsReleased?: boolean | undefined;
    } & {
        id?: string | undefined;
        kind?: string | undefined;
        status?: string | undefined;
        ownerAddress?: string | undefined;
        createTime?: Date | undefined;
        commitsEndTime?: Date | undefined;
        revealsEndTime?: Date | undefined;
        commitFee?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K in Exclude<keyof I["commitFee"], keyof Coin>]: never; }) | undefined;
        revealFee?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_1 in Exclude<keyof I["revealFee"], keyof Coin>]: never; }) | undefined;
        minimumBid?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_2 in Exclude<keyof I["minimumBid"], keyof Coin>]: never; }) | undefined;
        winnerAddresses?: (string[] & string[] & { [K_3 in Exclude<keyof I["winnerAddresses"], keyof string[]>]: never; }) | undefined;
        winningBids?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        }[] & ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_4 in Exclude<keyof I["winningBids"][number], keyof Coin>]: never; })[] & { [K_5 in Exclude<keyof I["winningBids"], keyof {
            denom?: string | undefined;
            amount?: string | undefined;
        }[]>]: never; }) | undefined;
        winningPrice?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_6 in Exclude<keyof I["winningPrice"], keyof Coin>]: never; }) | undefined;
        maxPrice?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_7 in Exclude<keyof I["maxPrice"], keyof Coin>]: never; }) | undefined;
        numProviders?: number | undefined;
        fundsReleased?: boolean | undefined;
    } & { [K_8 in Exclude<keyof I, keyof Auction>]: never; }>(object: I): Auction;
};
export declare const Auctions: {
    encode(message: Auctions, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Auctions;
    fromJSON(object: any): Auctions;
    toJSON(message: Auctions): unknown;
    fromPartial<I extends {
        auctions?: {
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddresses?: string[] | undefined;
            winningBids?: {
                denom?: string | undefined;
                amount?: string | undefined;
            }[] | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            maxPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        }[] | undefined;
    } & {
        auctions?: ({
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddresses?: string[] | undefined;
            winningBids?: {
                denom?: string | undefined;
                amount?: string | undefined;
            }[] | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            maxPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        }[] & ({
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddresses?: string[] | undefined;
            winningBids?: {
                denom?: string | undefined;
                amount?: string | undefined;
            }[] | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            maxPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        } & {
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K in Exclude<keyof I["auctions"][number]["commitFee"], keyof Coin>]: never; }) | undefined;
            revealFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_1 in Exclude<keyof I["auctions"][number]["revealFee"], keyof Coin>]: never; }) | undefined;
            minimumBid?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_2 in Exclude<keyof I["auctions"][number]["minimumBid"], keyof Coin>]: never; }) | undefined;
            winnerAddresses?: (string[] & string[] & { [K_3 in Exclude<keyof I["auctions"][number]["winnerAddresses"], keyof string[]>]: never; }) | undefined;
            winningBids?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            }[] & ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_4 in Exclude<keyof I["auctions"][number]["winningBids"][number], keyof Coin>]: never; })[] & { [K_5 in Exclude<keyof I["auctions"][number]["winningBids"], keyof {
                denom?: string | undefined;
                amount?: string | undefined;
            }[]>]: never; }) | undefined;
            winningPrice?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_6 in Exclude<keyof I["auctions"][number]["winningPrice"], keyof Coin>]: never; }) | undefined;
            maxPrice?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_7 in Exclude<keyof I["auctions"][number]["maxPrice"], keyof Coin>]: never; }) | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        } & { [K_8 in Exclude<keyof I["auctions"][number], keyof Auction>]: never; })[] & { [K_9 in Exclude<keyof I["auctions"], keyof {
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddresses?: string[] | undefined;
            winningBids?: {
                denom?: string | undefined;
                amount?: string | undefined;
            }[] | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            maxPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        }[]>]: never; }) | undefined;
    } & { [K_10 in Exclude<keyof I, "auctions">]: never; }>(object: I): Auctions;
};
export declare const Bid: {
    encode(message: Bid, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Bid;
    fromJSON(object: any): Bid;
    toJSON(message: Bid): unknown;
    fromPartial<I extends {
        auctionId?: string | undefined;
        bidderAddress?: string | undefined;
        status?: string | undefined;
        commitHash?: string | undefined;
        commitTime?: Date | undefined;
        commitFee?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        revealTime?: Date | undefined;
        revealFee?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        bidAmount?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
    } & {
        auctionId?: string | undefined;
        bidderAddress?: string | undefined;
        status?: string | undefined;
        commitHash?: string | undefined;
        commitTime?: Date | undefined;
        commitFee?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K in Exclude<keyof I["commitFee"], keyof Coin>]: never; }) | undefined;
        revealTime?: Date | undefined;
        revealFee?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_1 in Exclude<keyof I["revealFee"], keyof Coin>]: never; }) | undefined;
        bidAmount?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_2 in Exclude<keyof I["bidAmount"], keyof Coin>]: never; }) | undefined;
    } & { [K_3 in Exclude<keyof I, keyof Bid>]: never; }>(object: I): Bid;
};
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export type DeepPartial<T> = T extends Builtin ? T : T extends Long ? string | number | Long : T extends Array<infer U> ? Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
type KeysOfUnion<T> = T extends T ? keyof T : never;
export type Exact<P, I extends P> = P extends Builtin ? P : P & {
    [K in keyof P]: Exact<P[K], I[K]>;
} & {
    [K in Exclude<keyof I, KeysOfUnion<P>>]: never;
};
export {};
