import { Duration } from "../../../google/protobuf/duration";
import { Coin } from "../../../cosmos/base/v1beta1/coin";
import { Auction, Bid, Params } from "./auction";
import Long from "long";
import _m0 from "protobufjs/minimal";
export declare const protobufPackage = "cerc.auction.v1";
/** MsgCreateAuction defines a create auction message */
export interface MsgCreateAuction {
    /** Address of the signer */
    signer: string;
    /** Auction kind (vickrey | provider) */
    kind: string;
    /** Duration of the commits phase in seconds */
    commitsDuration?: Duration;
    /** Duration of the reveals phase in seconds */
    revealsDuration?: Duration;
    /** Commit fees */
    commitFee?: Coin;
    /** Reveal fees */
    revealFee?: Coin;
    /**
     * Minimum acceptable bid amount
     * Only applicable in vickrey auctions
     */
    minimumBid?: Coin;
    /**
     * Maximum acceptable bid amount
     * Only applicable in provider auctions
     */
    maxPrice?: Coin;
    /**
     * Number of desired providers (num of auction winners)
     * Only applicable in provider auctions
     */
    numProviders: number;
}
/** MsgCreateAuctionResponse returns the details of the created auction */
export interface MsgCreateAuctionResponse {
    /** Auction details */
    auction?: Auction;
}
/** CommitBid defines the message to commit a bid */
export interface MsgCommitBid {
    /** Auction id */
    auctionId: string;
    /** Commit Hash */
    commitHash: string;
    /** Address of the signer */
    signer: string;
}
/** MsgCommitBidResponse returns the state of the auction after the bid creation */
export interface MsgCommitBidResponse {
    /** Auction details */
    bid?: Bid;
}
/** RevealBid defines the message to reveal a bid */
export interface MsgRevealBid {
    /** Auction id */
    auctionId: string;
    /** Commit Hash */
    reveal: string;
    /** Address of the signer */
    signer: string;
}
/** MsgRevealBidResponse returns the state of the auction after the bid reveal */
export interface MsgRevealBidResponse {
    /** Auction details */
    auction?: Auction;
}
/** MsgUpdateParams is the Msg/UpdateParams request type. */
export interface MsgUpdateParams {
    /**
     * authority is the address that controls the module (defaults to x/gov unless
     * overwritten).
     */
    authority: string;
    /**
     * params defines the x/auction parameters to update.
     *
     * NOTE: All parameters must be supplied.
     */
    params?: Params;
}
/**
 * MsgUpdateParamsResponse defines the response structure for executing a
 * MsgUpdateParams message.
 */
export interface MsgUpdateParamsResponse {
}
/** ReleaseFunds defines the message to pay the winners of provider auctions */
export interface MsgReleaseFunds {
    /** Auction id */
    auctionId: string;
    /** Address of the signer */
    signer: string;
}
/** MsgReleaseFundsResponse returns the state of the auction after releasing the funds */
export interface MsgReleaseFundsResponse {
    /** Auction details */
    auction?: Auction;
}
export declare const MsgCreateAuction: {
    encode(message: MsgCreateAuction, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): MsgCreateAuction;
    fromJSON(object: any): MsgCreateAuction;
    toJSON(message: MsgCreateAuction): unknown;
    fromPartial<I extends {
        signer?: string | undefined;
        kind?: string | undefined;
        commitsDuration?: {
            seconds?: string | number | Long.Long | undefined;
            nanos?: number | undefined;
        } | undefined;
        revealsDuration?: {
            seconds?: string | number | Long.Long | undefined;
            nanos?: number | undefined;
        } | undefined;
        commitFee?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        revealFee?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        minimumBid?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        maxPrice?: {
            denom?: string | undefined;
            amount?: string | undefined;
        } | undefined;
        numProviders?: number | undefined;
    } & {
        signer?: string | undefined;
        kind?: string | undefined;
        commitsDuration?: ({
            seconds?: string | number | Long.Long | undefined;
            nanos?: number | undefined;
        } & {
            seconds?: string | number | (Long.Long & {
                high: number;
                low: number;
                unsigned: boolean;
                add: (addend: string | number | Long.Long) => Long.Long;
                and: (other: string | number | Long.Long) => Long.Long;
                compare: (other: string | number | Long.Long) => number;
                comp: (other: string | number | Long.Long) => number;
                divide: (divisor: string | number | Long.Long) => Long.Long;
                div: (divisor: string | number | Long.Long) => Long.Long;
                equals: (other: string | number | Long.Long) => boolean;
                eq: (other: string | number | Long.Long) => boolean;
                getHighBits: () => number;
                getHighBitsUnsigned: () => number;
                getLowBits: () => number;
                getLowBitsUnsigned: () => number;
                getNumBitsAbs: () => number;
                greaterThan: (other: string | number | Long.Long) => boolean;
                gt: (other: string | number | Long.Long) => boolean;
                greaterThanOrEqual: (other: string | number | Long.Long) => boolean;
                gte: (other: string | number | Long.Long) => boolean;
                isEven: () => boolean;
                isNegative: () => boolean;
                isOdd: () => boolean;
                isPositive: () => boolean;
                isZero: () => boolean;
                lessThan: (other: string | number | Long.Long) => boolean;
                lt: (other: string | number | Long.Long) => boolean;
                lessThanOrEqual: (other: string | number | Long.Long) => boolean;
                lte: (other: string | number | Long.Long) => boolean;
                modulo: (other: string | number | Long.Long) => Long.Long;
                mod: (other: string | number | Long.Long) => Long.Long;
                multiply: (multiplier: string | number | Long.Long) => Long.Long;
                mul: (multiplier: string | number | Long.Long) => Long.Long;
                negate: () => Long.Long;
                neg: () => Long.Long;
                not: () => Long.Long;
                notEquals: (other: string | number | Long.Long) => boolean;
                neq: (other: string | number | Long.Long) => boolean;
                or: (other: string | number | Long.Long) => Long.Long;
                shiftLeft: (numBits: number | Long.Long) => Long.Long;
                shl: (numBits: number | Long.Long) => Long.Long;
                shiftRight: (numBits: number | Long.Long) => Long.Long;
                shr: (numBits: number | Long.Long) => Long.Long;
                shiftRightUnsigned: (numBits: number | Long.Long) => Long.Long;
                shru: (numBits: number | Long.Long) => Long.Long;
                subtract: (subtrahend: string | number | Long.Long) => Long.Long;
                sub: (subtrahend: string | number | Long.Long) => Long.Long;
                toInt: () => number;
                toNumber: () => number;
                toBytes: (le?: boolean | undefined) => number[];
                toBytesLE: () => number[];
                toBytesBE: () => number[];
                toSigned: () => Long.Long;
                toString: (radix?: number | undefined) => string;
                toUnsigned: () => Long.Long;
                xor: (other: string | number | Long.Long) => Long.Long;
            } & { [K in Exclude<keyof I["commitsDuration"]["seconds"], keyof Long.Long>]: never; }) | undefined;
            nanos?: number | undefined;
        } & { [K_1 in Exclude<keyof I["commitsDuration"], keyof Duration>]: never; }) | undefined;
        revealsDuration?: ({
            seconds?: string | number | Long.Long | undefined;
            nanos?: number | undefined;
        } & {
            seconds?: string | number | (Long.Long & {
                high: number;
                low: number;
                unsigned: boolean;
                add: (addend: string | number | Long.Long) => Long.Long;
                and: (other: string | number | Long.Long) => Long.Long;
                compare: (other: string | number | Long.Long) => number;
                comp: (other: string | number | Long.Long) => number;
                divide: (divisor: string | number | Long.Long) => Long.Long;
                div: (divisor: string | number | Long.Long) => Long.Long;
                equals: (other: string | number | Long.Long) => boolean;
                eq: (other: string | number | Long.Long) => boolean;
                getHighBits: () => number;
                getHighBitsUnsigned: () => number;
                getLowBits: () => number;
                getLowBitsUnsigned: () => number;
                getNumBitsAbs: () => number;
                greaterThan: (other: string | number | Long.Long) => boolean;
                gt: (other: string | number | Long.Long) => boolean;
                greaterThanOrEqual: (other: string | number | Long.Long) => boolean;
                gte: (other: string | number | Long.Long) => boolean;
                isEven: () => boolean;
                isNegative: () => boolean;
                isOdd: () => boolean;
                isPositive: () => boolean;
                isZero: () => boolean;
                lessThan: (other: string | number | Long.Long) => boolean;
                lt: (other: string | number | Long.Long) => boolean;
                lessThanOrEqual: (other: string | number | Long.Long) => boolean;
                lte: (other: string | number | Long.Long) => boolean;
                modulo: (other: string | number | Long.Long) => Long.Long;
                mod: (other: string | number | Long.Long) => Long.Long;
                multiply: (multiplier: string | number | Long.Long) => Long.Long;
                mul: (multiplier: string | number | Long.Long) => Long.Long;
                negate: () => Long.Long;
                neg: () => Long.Long;
                not: () => Long.Long;
                notEquals: (other: string | number | Long.Long) => boolean;
                neq: (other: string | number | Long.Long) => boolean;
                or: (other: string | number | Long.Long) => Long.Long;
                shiftLeft: (numBits: number | Long.Long) => Long.Long;
                shl: (numBits: number | Long.Long) => Long.Long;
                shiftRight: (numBits: number | Long.Long) => Long.Long;
                shr: (numBits: number | Long.Long) => Long.Long;
                shiftRightUnsigned: (numBits: number | Long.Long) => Long.Long;
                shru: (numBits: number | Long.Long) => Long.Long;
                subtract: (subtrahend: string | number | Long.Long) => Long.Long;
                sub: (subtrahend: string | number | Long.Long) => Long.Long;
                toInt: () => number;
                toNumber: () => number;
                toBytes: (le?: boolean | undefined) => number[];
                toBytesLE: () => number[];
                toBytesBE: () => number[];
                toSigned: () => Long.Long;
                toString: (radix?: number | undefined) => string;
                toUnsigned: () => Long.Long;
                xor: (other: string | number | Long.Long) => Long.Long;
            } & { [K_2 in Exclude<keyof I["revealsDuration"]["seconds"], keyof Long.Long>]: never; }) | undefined;
            nanos?: number | undefined;
        } & { [K_3 in Exclude<keyof I["revealsDuration"], keyof Duration>]: never; }) | undefined;
        commitFee?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_4 in Exclude<keyof I["commitFee"], keyof Coin>]: never; }) | undefined;
        revealFee?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_5 in Exclude<keyof I["revealFee"], keyof Coin>]: never; }) | undefined;
        minimumBid?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_6 in Exclude<keyof I["minimumBid"], keyof Coin>]: never; }) | undefined;
        maxPrice?: ({
            denom?: string | undefined;
            amount?: string | undefined;
        } & {
            denom?: string | undefined;
            amount?: string | undefined;
        } & { [K_7 in Exclude<keyof I["maxPrice"], keyof Coin>]: never; }) | undefined;
        numProviders?: number | undefined;
    } & { [K_8 in Exclude<keyof I, keyof MsgCreateAuction>]: never; }>(object: I): MsgCreateAuction;
};
export declare const MsgCreateAuctionResponse: {
    encode(message: MsgCreateAuctionResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): MsgCreateAuctionResponse;
    fromJSON(object: any): MsgCreateAuctionResponse;
    toJSON(message: MsgCreateAuctionResponse): unknown;
    fromPartial<I extends {
        auction?: {
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddresses?: string[] | undefined;
            winningBids?: {
                denom?: string | undefined;
                amount?: string | undefined;
            }[] | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            maxPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        } | undefined;
    } & {
        auction?: ({
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddresses?: string[] | undefined;
            winningBids?: {
                denom?: string | undefined;
                amount?: string | undefined;
            }[] | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            maxPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        } & {
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K in Exclude<keyof I["auction"]["commitFee"], keyof Coin>]: never; }) | undefined;
            revealFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_1 in Exclude<keyof I["auction"]["revealFee"], keyof Coin>]: never; }) | undefined;
            minimumBid?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_2 in Exclude<keyof I["auction"]["minimumBid"], keyof Coin>]: never; }) | undefined;
            winnerAddresses?: (string[] & string[] & { [K_3 in Exclude<keyof I["auction"]["winnerAddresses"], keyof string[]>]: never; }) | undefined;
            winningBids?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            }[] & ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_4 in Exclude<keyof I["auction"]["winningBids"][number], keyof Coin>]: never; })[] & { [K_5 in Exclude<keyof I["auction"]["winningBids"], keyof {
                denom?: string | undefined;
                amount?: string | undefined;
            }[]>]: never; }) | undefined;
            winningPrice?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_6 in Exclude<keyof I["auction"]["winningPrice"], keyof Coin>]: never; }) | undefined;
            maxPrice?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_7 in Exclude<keyof I["auction"]["maxPrice"], keyof Coin>]: never; }) | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        } & { [K_8 in Exclude<keyof I["auction"], keyof Auction>]: never; }) | undefined;
    } & { [K_9 in Exclude<keyof I, "auction">]: never; }>(object: I): MsgCreateAuctionResponse;
};
export declare const MsgCommitBid: {
    encode(message: MsgCommitBid, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): MsgCommitBid;
    fromJSON(object: any): MsgCommitBid;
    toJSON(message: MsgCommitBid): unknown;
    fromPartial<I extends {
        auctionId?: string | undefined;
        commitHash?: string | undefined;
        signer?: string | undefined;
    } & {
        auctionId?: string | undefined;
        commitHash?: string | undefined;
        signer?: string | undefined;
    } & { [K in Exclude<keyof I, keyof MsgCommitBid>]: never; }>(object: I): MsgCommitBid;
};
export declare const MsgCommitBidResponse: {
    encode(message: MsgCommitBidResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): MsgCommitBidResponse;
    fromJSON(object: any): MsgCommitBidResponse;
    toJSON(message: MsgCommitBidResponse): unknown;
    fromPartial<I extends {
        bid?: {
            auctionId?: string | undefined;
            bidderAddress?: string | undefined;
            status?: string | undefined;
            commitHash?: string | undefined;
            commitTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealTime?: Date | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            bidAmount?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        } | undefined;
    } & {
        bid?: ({
            auctionId?: string | undefined;
            bidderAddress?: string | undefined;
            status?: string | undefined;
            commitHash?: string | undefined;
            commitTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealTime?: Date | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            bidAmount?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
        } & {
            auctionId?: string | undefined;
            bidderAddress?: string | undefined;
            status?: string | undefined;
            commitHash?: string | undefined;
            commitTime?: Date | undefined;
            commitFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K in Exclude<keyof I["bid"]["commitFee"], keyof Coin>]: never; }) | undefined;
            revealTime?: Date | undefined;
            revealFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_1 in Exclude<keyof I["bid"]["revealFee"], keyof Coin>]: never; }) | undefined;
            bidAmount?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_2 in Exclude<keyof I["bid"]["bidAmount"], keyof Coin>]: never; }) | undefined;
        } & { [K_3 in Exclude<keyof I["bid"], keyof Bid>]: never; }) | undefined;
    } & { [K_4 in Exclude<keyof I, "bid">]: never; }>(object: I): MsgCommitBidResponse;
};
export declare const MsgRevealBid: {
    encode(message: MsgRevealBid, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): MsgRevealBid;
    fromJSON(object: any): MsgRevealBid;
    toJSON(message: MsgRevealBid): unknown;
    fromPartial<I extends {
        auctionId?: string | undefined;
        reveal?: string | undefined;
        signer?: string | undefined;
    } & {
        auctionId?: string | undefined;
        reveal?: string | undefined;
        signer?: string | undefined;
    } & { [K in Exclude<keyof I, keyof MsgRevealBid>]: never; }>(object: I): MsgRevealBid;
};
export declare const MsgRevealBidResponse: {
    encode(message: MsgRevealBidResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): MsgRevealBidResponse;
    fromJSON(object: any): MsgRevealBidResponse;
    toJSON(message: MsgRevealBidResponse): unknown;
    fromPartial<I extends {
        auction?: {
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddresses?: string[] | undefined;
            winningBids?: {
                denom?: string | undefined;
                amount?: string | undefined;
            }[] | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            maxPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        } | undefined;
    } & {
        auction?: ({
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddresses?: string[] | undefined;
            winningBids?: {
                denom?: string | undefined;
                amount?: string | undefined;
            }[] | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            maxPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        } & {
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K in Exclude<keyof I["auction"]["commitFee"], keyof Coin>]: never; }) | undefined;
            revealFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_1 in Exclude<keyof I["auction"]["revealFee"], keyof Coin>]: never; }) | undefined;
            minimumBid?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_2 in Exclude<keyof I["auction"]["minimumBid"], keyof Coin>]: never; }) | undefined;
            winnerAddresses?: (string[] & string[] & { [K_3 in Exclude<keyof I["auction"]["winnerAddresses"], keyof string[]>]: never; }) | undefined;
            winningBids?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            }[] & ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_4 in Exclude<keyof I["auction"]["winningBids"][number], keyof Coin>]: never; })[] & { [K_5 in Exclude<keyof I["auction"]["winningBids"], keyof {
                denom?: string | undefined;
                amount?: string | undefined;
            }[]>]: never; }) | undefined;
            winningPrice?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_6 in Exclude<keyof I["auction"]["winningPrice"], keyof Coin>]: never; }) | undefined;
            maxPrice?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_7 in Exclude<keyof I["auction"]["maxPrice"], keyof Coin>]: never; }) | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        } & { [K_8 in Exclude<keyof I["auction"], keyof Auction>]: never; }) | undefined;
    } & { [K_9 in Exclude<keyof I, "auction">]: never; }>(object: I): MsgRevealBidResponse;
};
export declare const MsgUpdateParams: {
    encode(message: MsgUpdateParams, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): MsgUpdateParams;
    fromJSON(object: any): MsgUpdateParams;
    toJSON(message: MsgUpdateParams): unknown;
    fromPartial<I extends {
        authority?: string | undefined;
        params?: {} | undefined;
    } & {
        authority?: string | undefined;
        params?: ({} & {} & { [K in Exclude<keyof I["params"], never>]: never; }) | undefined;
    } & { [K_1 in Exclude<keyof I, keyof MsgUpdateParams>]: never; }>(object: I): MsgUpdateParams;
};
export declare const MsgUpdateParamsResponse: {
    encode(_: MsgUpdateParamsResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): MsgUpdateParamsResponse;
    fromJSON(_: any): MsgUpdateParamsResponse;
    toJSON(_: MsgUpdateParamsResponse): unknown;
    fromPartial<I extends {} & {} & { [K in Exclude<keyof I, never>]: never; }>(_: I): MsgUpdateParamsResponse;
};
export declare const MsgReleaseFunds: {
    encode(message: MsgReleaseFunds, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): MsgReleaseFunds;
    fromJSON(object: any): MsgReleaseFunds;
    toJSON(message: MsgReleaseFunds): unknown;
    fromPartial<I extends {
        auctionId?: string | undefined;
        signer?: string | undefined;
    } & {
        auctionId?: string | undefined;
        signer?: string | undefined;
    } & { [K in Exclude<keyof I, keyof MsgReleaseFunds>]: never; }>(object: I): MsgReleaseFunds;
};
export declare const MsgReleaseFundsResponse: {
    encode(message: MsgReleaseFundsResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): MsgReleaseFundsResponse;
    fromJSON(object: any): MsgReleaseFundsResponse;
    toJSON(message: MsgReleaseFundsResponse): unknown;
    fromPartial<I extends {
        auction?: {
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddresses?: string[] | undefined;
            winningBids?: {
                denom?: string | undefined;
                amount?: string | undefined;
            }[] | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            maxPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        } | undefined;
    } & {
        auction?: ({
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            revealFee?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            minimumBid?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            winnerAddresses?: string[] | undefined;
            winningBids?: {
                denom?: string | undefined;
                amount?: string | undefined;
            }[] | undefined;
            winningPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            maxPrice?: {
                denom?: string | undefined;
                amount?: string | undefined;
            } | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        } & {
            id?: string | undefined;
            kind?: string | undefined;
            status?: string | undefined;
            ownerAddress?: string | undefined;
            createTime?: Date | undefined;
            commitsEndTime?: Date | undefined;
            revealsEndTime?: Date | undefined;
            commitFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K in Exclude<keyof I["auction"]["commitFee"], keyof Coin>]: never; }) | undefined;
            revealFee?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_1 in Exclude<keyof I["auction"]["revealFee"], keyof Coin>]: never; }) | undefined;
            minimumBid?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_2 in Exclude<keyof I["auction"]["minimumBid"], keyof Coin>]: never; }) | undefined;
            winnerAddresses?: (string[] & string[] & { [K_3 in Exclude<keyof I["auction"]["winnerAddresses"], keyof string[]>]: never; }) | undefined;
            winningBids?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            }[] & ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_4 in Exclude<keyof I["auction"]["winningBids"][number], keyof Coin>]: never; })[] & { [K_5 in Exclude<keyof I["auction"]["winningBids"], keyof {
                denom?: string | undefined;
                amount?: string | undefined;
            }[]>]: never; }) | undefined;
            winningPrice?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_6 in Exclude<keyof I["auction"]["winningPrice"], keyof Coin>]: never; }) | undefined;
            maxPrice?: ({
                denom?: string | undefined;
                amount?: string | undefined;
            } & {
                denom?: string | undefined;
                amount?: string | undefined;
            } & { [K_7 in Exclude<keyof I["auction"]["maxPrice"], keyof Coin>]: never; }) | undefined;
            numProviders?: number | undefined;
            fundsReleased?: boolean | undefined;
        } & { [K_8 in Exclude<keyof I["auction"], keyof Auction>]: never; }) | undefined;
    } & { [K_9 in Exclude<keyof I, "auction">]: never; }>(object: I): MsgReleaseFundsResponse;
};
/** Tx defines the gRPC tx interface */
export interface Msg {
    /** CreateAuction is the command for creating an auction */
    CreateAuction(request: MsgCreateAuction): Promise<MsgCreateAuctionResponse>;
    /** CommitBid is the command for committing a bid */
    CommitBid(request: MsgCommitBid): Promise<MsgCommitBidResponse>;
    /** RevealBid is the command for revealing a bid */
    RevealBid(request: MsgRevealBid): Promise<MsgRevealBidResponse>;
    /**
     * UpdateParams defines an operation for updating the x/staking module
     * parameters.
     */
    UpdateParams(request: MsgUpdateParams): Promise<MsgUpdateParamsResponse>;
    /** ReleaseFunds is the command for paying the winners of provider auctions */
    ReleaseFunds(request: MsgReleaseFunds): Promise<MsgReleaseFundsResponse>;
}
export declare class MsgClientImpl implements Msg {
    private readonly rpc;
    constructor(rpc: Rpc);
    CreateAuction(request: MsgCreateAuction): Promise<MsgCreateAuctionResponse>;
    CommitBid(request: MsgCommitBid): Promise<MsgCommitBidResponse>;
    RevealBid(request: MsgRevealBid): Promise<MsgRevealBidResponse>;
    UpdateParams(request: MsgUpdateParams): Promise<MsgUpdateParamsResponse>;
    ReleaseFunds(request: MsgReleaseFunds): Promise<MsgReleaseFundsResponse>;
}
interface Rpc {
    request(service: string, method: string, data: Uint8Array): Promise<Uint8Array>;
}
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export type DeepPartial<T> = T extends Builtin ? T : T extends Long ? string | number | Long : T extends Array<infer U> ? Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
type KeysOfUnion<T> = T extends T ? keyof T : never;
export type Exact<P, I extends P> = P extends Builtin ? P : P & {
    [K in keyof P]: Exact<P[K], I[K]>;
} & {
    [K in Exclude<keyof I, KeysOfUnion<P>>]: never;
};
export {};
