/* eslint-disable */
import { Coin } from "../../../cosmos/base/v1beta1/coin";
import { Timestamp } from "../../../google/protobuf/timestamp";
import Long from "long";
import _m0 from "protobufjs/minimal";

export const protobufPackage = "cerc.auction.v1";

/** Params defines the auction module parameters */
export interface Params {}

/** Auction represents a sealed-bid on-chain auction */
export interface Auction {
  id: string;
  /** Auction kind (vickrey | provider) */
  kind: string;
  status: string;
  /** Address of the creator of the auction */
  ownerAddress: string;
  /** Timestamp at which the auction was created */
  createTime?: Date;
  /** Timestamp at which the commits phase concluded */
  commitsEndTime?: Date;
  /** Timestamp at which the reveals phase concluded */
  revealsEndTime?: Date;
  /**
   * Commit and reveal fees must both be paid when committing a bid
   * Reveal fee is returned only if the bid is revealed
   */
  commitFee?: Coin;
  revealFee?: Coin;
  /**
   * Minimum acceptable bid amount for a valid commit
   * Only applicable in vickrey auctions
   */
  minimumBid?: Coin;
  /**
   * Addresses of the winners
   * (single winner for vickrey auction)
   * (multiple winners for provider auctions)
   */
  winnerAddresses: string[];
  /** Winning bids, i.e. the best bids */
  winningBids: Coin[];
  /**
   * Auction winning price
   * vickrey auction: second highest bid, paid by the winner
   * provider auction: higest bid amongst winning_bids, paid by auction creator
   * to each winner
   */
  winningPrice?: Coin;
  /**
   * Maximum acceptable bid amount for a valid commit
   * Only applicable in provider auctions
   */
  maxPrice?: Coin;
  /**
   * Number of desired providers (num of auction winners)
   * Only applicable in provider auctions
   */
  numProviders: number;
  fundsReleased: boolean;
}

/** Auctions represent all the auctions in the module */
export interface Auctions {
  auctions: Auction[];
}

/** Bid represents a sealed bid (commit) made during the auction */
export interface Bid {
  auctionId: string;
  bidderAddress: string;
  status: string;
  commitHash: string;
  commitTime?: Date;
  commitFee?: Coin;
  revealTime?: Date;
  revealFee?: Coin;
  bidAmount?: Coin;
}

function createBaseParams(): Params {
  return {};
}

export const Params = {
  encode(_: Params, writer: _m0.Writer = _m0.Writer.create()): _m0.Writer {
    return writer;
  },

  decode(input: _m0.Reader | Uint8Array, length?: number): Params {
    const reader = input instanceof _m0.Reader ? input : new _m0.Reader(input);
    let end = length === undefined ? reader.len : reader.pos + length;
    const message = createBaseParams();
    while (reader.pos < end) {
      const tag = reader.uint32();
      switch (tag >>> 3) {
        default:
          reader.skipType(tag & 7);
          break;
      }
    }
    return message;
  },

  fromJSON(_: any): Params {
    return {};
  },

  toJSON(_: Params): unknown {
    const obj: any = {};
    return obj;
  },

  fromPartial<I extends Exact<DeepPartial<Params>, I>>(_: I): Params {
    const message = createBaseParams();
    return message;
  },
};

function createBaseAuction(): Auction {
  return {
    id: "",
    kind: "",
    status: "",
    ownerAddress: "",
    createTime: undefined,
    commitsEndTime: undefined,
    revealsEndTime: undefined,
    commitFee: undefined,
    revealFee: undefined,
    minimumBid: undefined,
    winnerAddresses: [],
    winningBids: [],
    winningPrice: undefined,
    maxPrice: undefined,
    numProviders: 0,
    fundsReleased: false,
  };
}

export const Auction = {
  encode(
    message: Auction,
    writer: _m0.Writer = _m0.Writer.create()
  ): _m0.Writer {
    if (message.id !== "") {
      writer.uint32(10).string(message.id);
    }
    if (message.kind !== "") {
      writer.uint32(18).string(message.kind);
    }
    if (message.status !== "") {
      writer.uint32(26).string(message.status);
    }
    if (message.ownerAddress !== "") {
      writer.uint32(34).string(message.ownerAddress);
    }
    if (message.createTime !== undefined) {
      Timestamp.encode(
        toTimestamp(message.createTime),
        writer.uint32(42).fork()
      ).ldelim();
    }
    if (message.commitsEndTime !== undefined) {
      Timestamp.encode(
        toTimestamp(message.commitsEndTime),
        writer.uint32(50).fork()
      ).ldelim();
    }
    if (message.revealsEndTime !== undefined) {
      Timestamp.encode(
        toTimestamp(message.revealsEndTime),
        writer.uint32(58).fork()
      ).ldelim();
    }
    if (message.commitFee !== undefined) {
      Coin.encode(message.commitFee, writer.uint32(66).fork()).ldelim();
    }
    if (message.revealFee !== undefined) {
      Coin.encode(message.revealFee, writer.uint32(74).fork()).ldelim();
    }
    if (message.minimumBid !== undefined) {
      Coin.encode(message.minimumBid, writer.uint32(82).fork()).ldelim();
    }
    for (const v of message.winnerAddresses) {
      writer.uint32(90).string(v!);
    }
    for (const v of message.winningBids) {
      Coin.encode(v!, writer.uint32(98).fork()).ldelim();
    }
    if (message.winningPrice !== undefined) {
      Coin.encode(message.winningPrice, writer.uint32(106).fork()).ldelim();
    }
    if (message.maxPrice !== undefined) {
      Coin.encode(message.maxPrice, writer.uint32(114).fork()).ldelim();
    }
    if (message.numProviders !== 0) {
      writer.uint32(120).int32(message.numProviders);
    }
    if (message.fundsReleased === true) {
      writer.uint32(128).bool(message.fundsReleased);
    }
    return writer;
  },

  decode(input: _m0.Reader | Uint8Array, length?: number): Auction {
    const reader = input instanceof _m0.Reader ? input : new _m0.Reader(input);
    let end = length === undefined ? reader.len : reader.pos + length;
    const message = createBaseAuction();
    while (reader.pos < end) {
      const tag = reader.uint32();
      switch (tag >>> 3) {
        case 1:
          message.id = reader.string();
          break;
        case 2:
          message.kind = reader.string();
          break;
        case 3:
          message.status = reader.string();
          break;
        case 4:
          message.ownerAddress = reader.string();
          break;
        case 5:
          message.createTime = fromTimestamp(
            Timestamp.decode(reader, reader.uint32())
          );
          break;
        case 6:
          message.commitsEndTime = fromTimestamp(
            Timestamp.decode(reader, reader.uint32())
          );
          break;
        case 7:
          message.revealsEndTime = fromTimestamp(
            Timestamp.decode(reader, reader.uint32())
          );
          break;
        case 8:
          message.commitFee = Coin.decode(reader, reader.uint32());
          break;
        case 9:
          message.revealFee = Coin.decode(reader, reader.uint32());
          break;
        case 10:
          message.minimumBid = Coin.decode(reader, reader.uint32());
          break;
        case 11:
          message.winnerAddresses.push(reader.string());
          break;
        case 12:
          message.winningBids.push(Coin.decode(reader, reader.uint32()));
          break;
        case 13:
          message.winningPrice = Coin.decode(reader, reader.uint32());
          break;
        case 14:
          message.maxPrice = Coin.decode(reader, reader.uint32());
          break;
        case 15:
          message.numProviders = reader.int32();
          break;
        case 16:
          message.fundsReleased = reader.bool();
          break;
        default:
          reader.skipType(tag & 7);
          break;
      }
    }
    return message;
  },

  fromJSON(object: any): Auction {
    return {
      id: isSet(object.id) ? String(object.id) : "",
      kind: isSet(object.kind) ? String(object.kind) : "",
      status: isSet(object.status) ? String(object.status) : "",
      ownerAddress: isSet(object.ownerAddress)
        ? String(object.ownerAddress)
        : "",
      createTime: isSet(object.createTime)
        ? fromJsonTimestamp(object.createTime)
        : undefined,
      commitsEndTime: isSet(object.commitsEndTime)
        ? fromJsonTimestamp(object.commitsEndTime)
        : undefined,
      revealsEndTime: isSet(object.revealsEndTime)
        ? fromJsonTimestamp(object.revealsEndTime)
        : undefined,
      commitFee: isSet(object.commitFee)
        ? Coin.fromJSON(object.commitFee)
        : undefined,
      revealFee: isSet(object.revealFee)
        ? Coin.fromJSON(object.revealFee)
        : undefined,
      minimumBid: isSet(object.minimumBid)
        ? Coin.fromJSON(object.minimumBid)
        : undefined,
      winnerAddresses: Array.isArray(object?.winnerAddresses)
        ? object.winnerAddresses.map((e: any) => String(e))
        : [],
      winningBids: Array.isArray(object?.winningBids)
        ? object.winningBids.map((e: any) => Coin.fromJSON(e))
        : [],
      winningPrice: isSet(object.winningPrice)
        ? Coin.fromJSON(object.winningPrice)
        : undefined,
      maxPrice: isSet(object.maxPrice)
        ? Coin.fromJSON(object.maxPrice)
        : undefined,
      numProviders: isSet(object.numProviders)
        ? Number(object.numProviders)
        : 0,
      fundsReleased: isSet(object.fundsReleased)
        ? Boolean(object.fundsReleased)
        : false,
    };
  },

  toJSON(message: Auction): unknown {
    const obj: any = {};
    message.id !== undefined && (obj.id = message.id);
    message.kind !== undefined && (obj.kind = message.kind);
    message.status !== undefined && (obj.status = message.status);
    message.ownerAddress !== undefined &&
      (obj.ownerAddress = message.ownerAddress);
    message.createTime !== undefined &&
      (obj.createTime = message.createTime.toISOString());
    message.commitsEndTime !== undefined &&
      (obj.commitsEndTime = message.commitsEndTime.toISOString());
    message.revealsEndTime !== undefined &&
      (obj.revealsEndTime = message.revealsEndTime.toISOString());
    message.commitFee !== undefined &&
      (obj.commitFee = message.commitFee
        ? Coin.toJSON(message.commitFee)
        : undefined);
    message.revealFee !== undefined &&
      (obj.revealFee = message.revealFee
        ? Coin.toJSON(message.revealFee)
        : undefined);
    message.minimumBid !== undefined &&
      (obj.minimumBid = message.minimumBid
        ? Coin.toJSON(message.minimumBid)
        : undefined);
    if (message.winnerAddresses) {
      obj.winnerAddresses = message.winnerAddresses.map((e) => e);
    } else {
      obj.winnerAddresses = [];
    }
    if (message.winningBids) {
      obj.winningBids = message.winningBids.map((e) =>
        e ? Coin.toJSON(e) : undefined
      );
    } else {
      obj.winningBids = [];
    }
    message.winningPrice !== undefined &&
      (obj.winningPrice = message.winningPrice
        ? Coin.toJSON(message.winningPrice)
        : undefined);
    message.maxPrice !== undefined &&
      (obj.maxPrice = message.maxPrice
        ? Coin.toJSON(message.maxPrice)
        : undefined);
    message.numProviders !== undefined &&
      (obj.numProviders = Math.round(message.numProviders));
    message.fundsReleased !== undefined &&
      (obj.fundsReleased = message.fundsReleased);
    return obj;
  },

  fromPartial<I extends Exact<DeepPartial<Auction>, I>>(object: I): Auction {
    const message = createBaseAuction();
    message.id = object.id ?? "";
    message.kind = object.kind ?? "";
    message.status = object.status ?? "";
    message.ownerAddress = object.ownerAddress ?? "";
    message.createTime = object.createTime ?? undefined;
    message.commitsEndTime = object.commitsEndTime ?? undefined;
    message.revealsEndTime = object.revealsEndTime ?? undefined;
    message.commitFee =
      object.commitFee !== undefined && object.commitFee !== null
        ? Coin.fromPartial(object.commitFee)
        : undefined;
    message.revealFee =
      object.revealFee !== undefined && object.revealFee !== null
        ? Coin.fromPartial(object.revealFee)
        : undefined;
    message.minimumBid =
      object.minimumBid !== undefined && object.minimumBid !== null
        ? Coin.fromPartial(object.minimumBid)
        : undefined;
    message.winnerAddresses = object.winnerAddresses?.map((e) => e) || [];
    message.winningBids =
      object.winningBids?.map((e) => Coin.fromPartial(e)) || [];
    message.winningPrice =
      object.winningPrice !== undefined && object.winningPrice !== null
        ? Coin.fromPartial(object.winningPrice)
        : undefined;
    message.maxPrice =
      object.maxPrice !== undefined && object.maxPrice !== null
        ? Coin.fromPartial(object.maxPrice)
        : undefined;
    message.numProviders = object.numProviders ?? 0;
    message.fundsReleased = object.fundsReleased ?? false;
    return message;
  },
};

function createBaseAuctions(): Auctions {
  return { auctions: [] };
}

export const Auctions = {
  encode(
    message: Auctions,
    writer: _m0.Writer = _m0.Writer.create()
  ): _m0.Writer {
    for (const v of message.auctions) {
      Auction.encode(v!, writer.uint32(10).fork()).ldelim();
    }
    return writer;
  },

  decode(input: _m0.Reader | Uint8Array, length?: number): Auctions {
    const reader = input instanceof _m0.Reader ? input : new _m0.Reader(input);
    let end = length === undefined ? reader.len : reader.pos + length;
    const message = createBaseAuctions();
    while (reader.pos < end) {
      const tag = reader.uint32();
      switch (tag >>> 3) {
        case 1:
          message.auctions.push(Auction.decode(reader, reader.uint32()));
          break;
        default:
          reader.skipType(tag & 7);
          break;
      }
    }
    return message;
  },

  fromJSON(object: any): Auctions {
    return {
      auctions: Array.isArray(object?.auctions)
        ? object.auctions.map((e: any) => Auction.fromJSON(e))
        : [],
    };
  },

  toJSON(message: Auctions): unknown {
    const obj: any = {};
    if (message.auctions) {
      obj.auctions = message.auctions.map((e) =>
        e ? Auction.toJSON(e) : undefined
      );
    } else {
      obj.auctions = [];
    }
    return obj;
  },

  fromPartial<I extends Exact<DeepPartial<Auctions>, I>>(object: I): Auctions {
    const message = createBaseAuctions();
    message.auctions =
      object.auctions?.map((e) => Auction.fromPartial(e)) || [];
    return message;
  },
};

function createBaseBid(): Bid {
  return {
    auctionId: "",
    bidderAddress: "",
    status: "",
    commitHash: "",
    commitTime: undefined,
    commitFee: undefined,
    revealTime: undefined,
    revealFee: undefined,
    bidAmount: undefined,
  };
}

export const Bid = {
  encode(message: Bid, writer: _m0.Writer = _m0.Writer.create()): _m0.Writer {
    if (message.auctionId !== "") {
      writer.uint32(10).string(message.auctionId);
    }
    if (message.bidderAddress !== "") {
      writer.uint32(18).string(message.bidderAddress);
    }
    if (message.status !== "") {
      writer.uint32(26).string(message.status);
    }
    if (message.commitHash !== "") {
      writer.uint32(34).string(message.commitHash);
    }
    if (message.commitTime !== undefined) {
      Timestamp.encode(
        toTimestamp(message.commitTime),
        writer.uint32(42).fork()
      ).ldelim();
    }
    if (message.commitFee !== undefined) {
      Coin.encode(message.commitFee, writer.uint32(50).fork()).ldelim();
    }
    if (message.revealTime !== undefined) {
      Timestamp.encode(
        toTimestamp(message.revealTime),
        writer.uint32(58).fork()
      ).ldelim();
    }
    if (message.revealFee !== undefined) {
      Coin.encode(message.revealFee, writer.uint32(66).fork()).ldelim();
    }
    if (message.bidAmount !== undefined) {
      Coin.encode(message.bidAmount, writer.uint32(74).fork()).ldelim();
    }
    return writer;
  },

  decode(input: _m0.Reader | Uint8Array, length?: number): Bid {
    const reader = input instanceof _m0.Reader ? input : new _m0.Reader(input);
    let end = length === undefined ? reader.len : reader.pos + length;
    const message = createBaseBid();
    while (reader.pos < end) {
      const tag = reader.uint32();
      switch (tag >>> 3) {
        case 1:
          message.auctionId = reader.string();
          break;
        case 2:
          message.bidderAddress = reader.string();
          break;
        case 3:
          message.status = reader.string();
          break;
        case 4:
          message.commitHash = reader.string();
          break;
        case 5:
          message.commitTime = fromTimestamp(
            Timestamp.decode(reader, reader.uint32())
          );
          break;
        case 6:
          message.commitFee = Coin.decode(reader, reader.uint32());
          break;
        case 7:
          message.revealTime = fromTimestamp(
            Timestamp.decode(reader, reader.uint32())
          );
          break;
        case 8:
          message.revealFee = Coin.decode(reader, reader.uint32());
          break;
        case 9:
          message.bidAmount = Coin.decode(reader, reader.uint32());
          break;
        default:
          reader.skipType(tag & 7);
          break;
      }
    }
    return message;
  },

  fromJSON(object: any): Bid {
    return {
      auctionId: isSet(object.auctionId) ? String(object.auctionId) : "",
      bidderAddress: isSet(object.bidderAddress)
        ? String(object.bidderAddress)
        : "",
      status: isSet(object.status) ? String(object.status) : "",
      commitHash: isSet(object.commitHash) ? String(object.commitHash) : "",
      commitTime: isSet(object.commitTime)
        ? fromJsonTimestamp(object.commitTime)
        : undefined,
      commitFee: isSet(object.commitFee)
        ? Coin.fromJSON(object.commitFee)
        : undefined,
      revealTime: isSet(object.revealTime)
        ? fromJsonTimestamp(object.revealTime)
        : undefined,
      revealFee: isSet(object.revealFee)
        ? Coin.fromJSON(object.revealFee)
        : undefined,
      bidAmount: isSet(object.bidAmount)
        ? Coin.fromJSON(object.bidAmount)
        : undefined,
    };
  },

  toJSON(message: Bid): unknown {
    const obj: any = {};
    message.auctionId !== undefined && (obj.auctionId = message.auctionId);
    message.bidderAddress !== undefined &&
      (obj.bidderAddress = message.bidderAddress);
    message.status !== undefined && (obj.status = message.status);
    message.commitHash !== undefined && (obj.commitHash = message.commitHash);
    message.commitTime !== undefined &&
      (obj.commitTime = message.commitTime.toISOString());
    message.commitFee !== undefined &&
      (obj.commitFee = message.commitFee
        ? Coin.toJSON(message.commitFee)
        : undefined);
    message.revealTime !== undefined &&
      (obj.revealTime = message.revealTime.toISOString());
    message.revealFee !== undefined &&
      (obj.revealFee = message.revealFee
        ? Coin.toJSON(message.revealFee)
        : undefined);
    message.bidAmount !== undefined &&
      (obj.bidAmount = message.bidAmount
        ? Coin.toJSON(message.bidAmount)
        : undefined);
    return obj;
  },

  fromPartial<I extends Exact<DeepPartial<Bid>, I>>(object: I): Bid {
    const message = createBaseBid();
    message.auctionId = object.auctionId ?? "";
    message.bidderAddress = object.bidderAddress ?? "";
    message.status = object.status ?? "";
    message.commitHash = object.commitHash ?? "";
    message.commitTime = object.commitTime ?? undefined;
    message.commitFee =
      object.commitFee !== undefined && object.commitFee !== null
        ? Coin.fromPartial(object.commitFee)
        : undefined;
    message.revealTime = object.revealTime ?? undefined;
    message.revealFee =
      object.revealFee !== undefined && object.revealFee !== null
        ? Coin.fromPartial(object.revealFee)
        : undefined;
    message.bidAmount =
      object.bidAmount !== undefined && object.bidAmount !== null
        ? Coin.fromPartial(object.bidAmount)
        : undefined;
    return message;
  },
};

type Builtin =
  | Date
  | Function
  | Uint8Array
  | string
  | number
  | boolean
  | undefined;

export type DeepPartial<T> = T extends Builtin
  ? T
  : T extends Long
  ? string | number | Long
  : T extends Array<infer U>
  ? Array<DeepPartial<U>>
  : T extends ReadonlyArray<infer U>
  ? ReadonlyArray<DeepPartial<U>>
  : T extends {}
  ? { [K in keyof T]?: DeepPartial<T[K]> }
  : Partial<T>;

type KeysOfUnion<T> = T extends T ? keyof T : never;
export type Exact<P, I extends P> = P extends Builtin
  ? P
  : P & { [K in keyof P]: Exact<P[K], I[K]> } & {
      [K in Exclude<keyof I, KeysOfUnion<P>>]: never;
    };

function toTimestamp(date: Date): Timestamp {
  const seconds = numberToLong(date.getTime() / 1_000);
  const nanos = (date.getTime() % 1_000) * 1_000_000;
  return { seconds, nanos };
}

function fromTimestamp(t: Timestamp): Date {
  let millis = t.seconds.toNumber() * 1_000;
  millis += t.nanos / 1_000_000;
  return new Date(millis);
}

function fromJsonTimestamp(o: any): Date {
  if (o instanceof Date) {
    return o;
  } else if (typeof o === "string") {
    return new Date(o);
  } else {
    return fromTimestamp(Timestamp.fromJSON(o));
  }
}

function numberToLong(number: number) {
  return Long.fromNumber(number);
}

if (_m0.util.Long !== Long) {
  _m0.util.Long = Long as any;
  _m0.configure();
}

function isSet(value: any): boolean {
  return value !== null && value !== undefined;
}
