import assert from 'assert';
import yaml from 'node-yaml';
import semver from 'semver';

import { Account, Registry } from '../index';

const DEFAULT_CHAIN_ID = 'laconic_9000-1';

export const ensureUpdatedConfig = async (path: string) => {
  const conf = await yaml.read(path);
  conf.record.version = semver.inc(conf.record.version, 'patch');
  await yaml.write(path, conf);

  return conf;
};

export const getBaseConfig = async (path: string) => {
  const conf = await yaml.read(path);
  conf.record.version = '0.0.1';

  return conf;
};

export const getConfig = () => {
  assert(process.env.PRIVATE_KEY);

  return {
    chainId: process.env.COSMOS_CHAIN_ID || DEFAULT_CHAIN_ID,
    privateKey: process.env.PRIVATE_KEY,
    rpcEndpoint: process.env.LACONICD_RPC_ENDPOINT || 'http://localhost:26657',
    gqlEndpoint: process.env.LACONICD_GQL_ENDPOINT || 'http://localhost:9473/api',
    fee: {
      amount: [{ denom: 'alnt', amount: '200000' }],
      gas: '200000'
    }
  };
};

export const createTestAccounts = async (numAccounts: number): Promise<Account[]> => {
  const accounts: Account[] = [];

  for (let i = 0; i < numAccounts; i++) {
    const mnemonic = Account.generateMnemonic();
    const account = await Account.generateFromMnemonic(mnemonic);
    await account.init();
    accounts.push(account);
  }

  return accounts;
};
