import { EncodeObject, GeneratedType } from '@cosmjs/proto-signing';

import { MsgCommitBidResponse, MsgCommitBid, MsgRevealBid, MsgRevealBidResponse, MsgCreateAuction, MsgCreateAuctionResponse, MsgReleaseFunds, MsgReleaseFundsResponse } from '../../../proto/cerc/auction/v1/tx';

export const typeUrlMsgCreateAuction = '/cerc.auction.v1.MsgCreateAuction';
export const typeUrlMsgCommitBid = '/cerc.auction.v1.MsgCommitBid';
export const typeUrlMsgCommitBidResponse = '/cerc.auction.v1.MsgCommitBidResponse';
export const typeUrlMsgRevealBid = '/cerc.auction.v1.MsgRevealBid';
export const typeUrlMsgRevealBidResponse = '/cerc.auction.v1.MsgRevealBidResponse';
export const typeUrlMsgCreateAuctionResponse = '/cerc.auction.v1.MsgCreateAuctionResponse';
export const typeUrlMsgReleaseFunds = '/cerc.auction.v1.MsgReleaseFunds';
export const typeUrlMsgReleaseFundsResponse = '/cerc.auction.v1.MsgReleaseFundsResponse';

export const auctionTypes: ReadonlyArray<[string, GeneratedType]> = [
  [typeUrlMsgCreateAuction, MsgCreateAuction],
  [typeUrlMsgCommitBid, MsgCommitBid],
  [typeUrlMsgCommitBidResponse, MsgCommitBidResponse],
  [typeUrlMsgRevealBid, MsgRevealBid],
  [typeUrlMsgRevealBidResponse, MsgRevealBidResponse],
  [typeUrlMsgCreateAuctionResponse, MsgCreateAuctionResponse],
  [typeUrlMsgReleaseFunds, MsgReleaseFunds],
  [typeUrlMsgReleaseFundsResponse, MsgReleaseFundsResponse]
];

export interface MsgCreateAuctionEncodeObject extends EncodeObject {
  readonly typeUrl: '/cerc.auction.v1.MsgCreateAuction';
  readonly value: Partial<MsgCreateAuction>;
}

export interface MsgCommitBidEncodeObject extends EncodeObject {
  readonly typeUrl: '/cerc.auction.v1.MsgCommitBid';
  readonly value: Partial<MsgCommitBid>;
}

export interface MsgRevealBidEncodeObject extends EncodeObject {
  readonly typeUrl: '/cerc.auction.v1.MsgRevealBid';
  readonly value: Partial<MsgRevealBid>;
}

export interface MsgReleaseFundsEncodeObject extends EncodeObject {
  readonly typeUrl: '/cerc.auction.v1.MsgReleaseFunds';
  readonly value: Partial<MsgReleaseFunds>;
}

export const INVALID_BID_ERROR = 'Bid is higher than max price';
export const RELEASE_FUNDS_ERROR = 'Auction funds already released';
export const OWNER_MISMATCH_ERROR = 'Only auction owner can release funds';
export const AUCTION_ERRORS = [INVALID_BID_ERROR, RELEASE_FUNDS_ERROR, OWNER_MISMATCH_ERROR];

export interface MessageMsgCommitBid {
  auctionId: string,
  commitHash: string,
}

export interface MessageMsgRevealBid {
  auctionId: string,
  reveal: string,
}

export interface MessageCreateVickreyAuction {
  commitsDuration: string;
  revealsDuration: string;
  denom: string;
  commitFee: string;
  revealFee: string;
  minimumBid: string;
}

export interface MessageCreateProviderAuction {
  commitsDuration: string;
  revealsDuration: string;
  denom: string;
  commitFee: string;
  revealFee: string;
  maxPrice: string;
  numProviders: number;
}

export interface MessageMsgReleaseFunds {
  auctionId: string
}
